Uses of Interface org.openqa.selenium.server.ResourceLocator (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Interface
org.openqa.selenium.server.ResourceLocator

Packages that use ResourceLocator
org.openqa.selenium.server | Provides the core Selenium Server classes.

Uses of ResourceLocator in org.openqa.selenium.server

Classes in org.openqa.selenium.server that implement ResourceLocator
`class` | `ClasspathResourceLocator`
`class` | `FsResourceLocator`

Methods in org.openqa.selenium.server with parameters of type ResourceLocator
`void` | `StaticContentHandler.addStaticContent(ResourceLocator locator)`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.